==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/ErrorsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.ErrorsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The error message associated with the cluster creation.
 * @property code The error code.
 * @property message The error message.
 */
public data class ErrorsArgs(
    public val code: Output<String>? = null,
    public val message: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.ErrorsArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.ErrorsArgs =
        com.pulumi.azurenative.hdinsight.inputs.ErrorsArgs.builder()
            .code(code?.applyValue({ args0 -> args0 }))
            .message(message?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ErrorsArgs].
 */
@PulumiTagMarker
public class ErrorsArgsBuilder internal constructor() {
    private var code: Output<String>? = null

    private var message: Output<String>? = null

    /**
     * @param value The error code.
     */
    @JvmName("rusjnkcwwckdxppd")
    public suspend fun code(`value`: Output<String>) {
        this.code = value
    }

    /**
     * @param value The error message.
     */
    @JvmName("awgtiykwyndqftoe")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value The error code.
     */
    @JvmName("chkdmyrujibgdsic")
    public suspend fun code(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.code = mapped
    }

    /**
     * @param value The error message.
     */
    @JvmName("gqotvnecsujwltiu")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    internal fun build(): ErrorsArgs = ErrorsArgs(
        code = code,
        message = message,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/ErrorsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.ErrorsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The error message associated with the cluster creation.
 * @property code The error code.
 * @property message The error message.
 */
public data class ErrorsArgs(
    public val code: Output<String>? = null,
    public val message: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.ErrorsArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.ErrorsArgs =
        com.pulumi.azurenative.hdinsight.inputs.ErrorsArgs.builder()
            .code(code?.applyValue({ args0 -> args0 }))
            .message(message?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ErrorsArgs].
 */
@PulumiTagMarker
public class ErrorsArgsBuilder internal constructor() {
    private var code: Output<String>? = null

    private var message: Output<String>? = null

    /**
     * @param value The error code.
     */
    @JvmName("qjfujoqgeahloekc")
    public suspend fun code(`value`: Output<String>) {
        this.code = value
    }

    /**
     * @param value The error message.
     */
    @JvmName("kvkwrexbhxwitbue")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value The error code.
     */
    @JvmName("jqubbshnocewymxc")
    public suspend fun code(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.code = mapped
    }

    /**
     * @param value The error message.
     */
    @JvmName("vupturooyymeqbcy")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    internal fun build(): ErrorsArgs = ErrorsArgs(
        code = code,
        message = message,
    )
}
